#
#
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

module Shell
  module Commands
    class CompactionState < Command
      def help
        <<~EOF
          Gets compaction status (MAJOR, MAJOR_AND_MINOR, MINOR, NONE) for a table:
          hbase> compaction_state 'ns1:t1'
          hbase> compaction_state 't1'
        EOF
      end

      def command(table_name)
        rv = admin.getCompactionState(table_name)
        formatter.row([rv])
        rv
      end
    end
  end
end
